from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='mkdocs-meta-manager',
    version='0.1.1',
    description='MkDocs plugin for managing meta tags across folders and files.',    
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords='mkdocs meta manager',
    url='https://github.com/timmeinerzhagen/mkdocs-meta-manager',
    author='Tim Jonas Meinerzhagen',
    author_email='tim@meinerzhagen.me',
    license='MIT',
    license_files = ('LICENSE'),
    classifiers=[
        "Operating System :: OS Independent",
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3 :: Only',
        "License :: OSI Approved :: MIT License",
        'Topic :: Documentation',
        'Topic :: Text Processing',
    ],
    python_requires='>=3.4',
    install_requires=[
        'mkdocs>=1.0',
        'jinja2'
    ],
    packages=find_packages(),
    entry_points={
        'mkdocs.plugins': [
            'meta-manager = mkdocs_meta_manager_plugin.plugin:MetaManagerPlugin'
        ]
    }
)


import re
import yaml
from pathlib import Path

from mkdocs.config import config_options
from mkdocs.plugins import BasePlugin

class MetaManagerPlugin(BasePlugin):
    config_scheme = (
        ('meta_filename', config_options.Type(str, default='.meta.yml')),
    )

    meta_files = {}

    def __init__(self):
        self.enabled = True

    def on_pre_build(self, config):
        pathlist = Path(config.docs_dir).rglob(self.config['meta_filename'])
        for path in pathlist:
            filepath = str(path)
            raw_path = filepath \
                .replace('/' + self.config['meta_filename'], '') \
                .replace(config.docs_dir + "/", '') \
                .replace(config.docs_dir, '')
            with open(filepath, "r") as stream:
                try:
                    self.meta_files[raw_path] = yaml.safe_load(stream)
                except yaml.YAMLError as exc:
                    print(exc)
        print(self.meta_files)
        

    def on_page_markdown(self, markdown, page, config, files):
        if not self.enabled:
            return markdown

        path_parts = page.file.src_path.split('/')
        for i in reversed(range(len(path_parts))):
            part = '/'.join(path_parts[0:i])
            if part in self.meta_files:
                for key, value in self.meta_files[part].items():
                    if not key in page.meta:
                        page.meta[key] = value

        print(page.meta)
        return markdown
